==> ejc-scientific-api-3.0.0-20250303.013559-4-sources.jar: com/ejianc/business/scientific/result/MethodReviewDetailVO.java <==
package com.ejianc.business.scientific.result;


import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工法管理-工法评审子表
 * 
 * @author generator
 * 
 */
public class MethodReviewDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Integer billState; // 单据状态（审批必须字段）
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private String memo; // 评审会议纪要
    private Date expirationDate; // 评审截止日期
    private String methodName; // 工法名称
    private Long methodId; // 工法id
    private Long methodPersonId; //  工法完成人id
    private String methodPersonName; // methodPersonName
    private Long parentOrgId; // 责任单位id
    private String parentOrgName; // parentOrgName
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private String approveId; // 评审专家id
    private String approveName; // 评审专家name
    private Long mid; // 主表id

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getExpirationDate() {
        return expirationDate;
    }

    public void setExpirationDate(Date expirationDate) {
        this.expirationDate = expirationDate;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Long getMethodId() {
        return methodId;
    }

    public void setMethodId(Long methodId) {
        this.methodId = methodId;
    }
    public Long getMethodPersonId() {
        return methodPersonId;
    }

    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }
    public String getApproveId() {
        return approveId;
    }

    public void setApproveId(String approveId) {
        this.approveId = approveId;
    }
    public String getApproveName() {
        return approveName;
    }

    public void setApproveName(String approveName) {
        this.approveName = approveName;
    }
    
}

==> ejc-scientific-api-3.0.0-20250303.064707-8-sources.jar: com/ejianc/business/scientific/result/MethodReviewDetailVO.java <==
package com.ejianc.business.scientific.result;


import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工法管理-工法评审子表
 * 
 * @author generator
 * 
 */
public class MethodReviewDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Integer billState; // 单据状态（审批必须字段）
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private String memo; // 评审会议纪要
    private Date expirationDate; // 评审截止日期
    private String methodName; // 工法名称
    private Long methodId; // 工法id
    private Long methodPersonId; //  工法完成人id
    private String methodPersonName; // methodPersonName
    private Long parentOrgId; // 责任单位id
    private String parentOrgName; // parentOrgName
    private Integer methodType; // 类别  1- 土木工程 2-房屋建筑工程 3-工业安装工程
    private String approveId; // 评审专家id
    private String approveName; // 评审专家name
    private Long mid; // 主表id

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Date getExpirationDate() {
        return expirationDate;
    }

    public void setExpirationDate(Date expirationDate) {
        this.expirationDate = expirationDate;
    }
    public String getMethodName() {
        return methodName;
    }

    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }
    public Long getMethodId() {
        return methodId;
    }

    public void setMethodId(Long methodId) {
        this.methodId = methodId;
    }
    public Long getMethodPersonId() {
        return methodPersonId;
    }

    public void setMethodPersonId(Long methodPersonId) {
        this.methodPersonId = methodPersonId;
    }
    public String getMethodPersonName() {
        return methodPersonName;
    }

    public void setMethodPersonName(String methodPersonName) {
        this.methodPersonName = methodPersonName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Integer getMethodType() {
        return methodType;
    }

    public void setMethodType(Integer methodType) {
        this.methodType = methodType;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public String getApproveId() {
        return approveId;
    }
    @ReferDeserialTransfer
    public void setApproveId(String approveId) {
        this.approveId = approveId;
    }
    public String getApproveName() {
        return approveName;
    }

    public void setApproveName(String approveName) {
        this.approveName = approveName;
    }
    
}
